pub struct AdjustmentEvent {
    pub adjustment_type: Option<String>,
    pub posted_date: Option<String>,
    pub adjustment_amount: Option<Box<Currency>>,
    pub adjustment_item_list: Option<Vec<AdjustmentItem>>,
}
AdjustmentEvent : An adjustment to the seller’s account.

Fields

adjustment_type: Option<String>

The type of adjustment. Possible values: * FBAInventoryReimbursement - An FBA inventory reimbursement to a seller’s account. This occurs if a seller’s inventory is damaged. * ReserveEvent - A reserve event that is generated at the time of a settlement period closing. This occurs when some money from a seller’s account is held back. * PostageBilling - The amount paid by a seller for shipping labels. * PostageRefund - The reimbursement of shipping labels purchased for orders that were canceled or refunded. * LostOrDamagedReimbursement - An Amazon Easy Ship reimbursement to a seller’s account for a package that we lost or damaged. * CanceledButPickedUpReimbursement - An Amazon Easy Ship reimbursement to a seller’s account. This occurs when a package is picked up and the order is subsequently canceled. This value is used only in the India marketplace. * ReimbursementClawback - An Amazon Easy Ship reimbursement clawback from a seller’s account. This occurs when a prior reimbursement is reversed. This value is used only in the India marketplace. * SellerRewards - An award credited to a seller’s account for their participation in an offer in the Seller Rewards program. Applies only to the India marketplace.

posted_date: Option<String>adjustment_amount: Option<Box<Currency>>adjustment_item_list: Option<Vec<AdjustmentItem>>

A list of information about items in an adjustment to the seller’s account.

Implementations

An adjustment to the seller’s account.